@@ -25,7 +25,7 @@ MCS <- function(X,p=seq(.1, .9, by=.1)) {
     X <- t(X) # Yiannis's original code had variables as rows
     U <- t(apply(X,1,edf)) #transpose cause apply transposes g(X), g:edf
     n    <- length(p)
-	res <- sapply(p, .MCSlower, U=U)
+    res <- sapply(p, .MCSlower, U=U)
 
     res <- list(mcs=res, p=p, call=theCall)
     oldClass(res) <- "MCS"
@@ -45,7 +45,6 @@ print.MCS <- function(x, ...){
     print(res)
     invisible(res)
 }
-show.MCS <- print.MCS
 
 summary.MCS <-  function(object, ...){
     print(object$call)
@@ -96,7 +95,6 @@ print.bootMCS <- function(x, ...){
     print(m)
     invisible(m)
 }
-show.bootMCS <- print.bootMCS
 
 summary.bootMCS <- function(object, alpha=.05, ...){
     cat("Multivariate conditional Spearman's rho.\n", object$R, " bootstrap samples were performed.\n\n",
@@ -108,47 +106,3 @@ summary.bootMCS <- function(object, alpha=.05, ...){
     res
 }
 
-test.MCS <- function(){
-  myMCS <- function(x,p){
-# First and second args are
-# x (dxn matrix) and p (vector of probabilities).
-
-    n <- dim(x)[2]
-    d <- dim(x)[1]
-    u <- t(apply(x,1,rank))/(n+1)# schmid and schmidt use n not n+1
-    
-    rho <- numeric(length(p))
-    for(k in 1:length(p)) {
-      Diff <- p[k] - u
-      Diff[Diff<0] <- 0
-      Prod <- apply(Diff,2,prod)
-      
-      num <- mean(Prod) - ((p[k]^2)/2)^d
-      den <- (p[k]^(d+1)) / (d+1) - (0.5*p[k]^2)^d
-      rho[k] <- num/den
-    }
-
-    rho
-   }
-# simulated data - dimension 2
-   n <- 1000
-   by <- 0.01
-   p <- seq(by,1-by,by=by)
-   data <- rbind(rnorm(n),rnorm(n))
-
-   tmRl <- MCS(t(data),p)
-   myRl <- myMCS(data,tmRl$p)
-   
-   checkEqualsNumeric(myRl,tmRl$mcs,msg="MCS: independent normal data")
-   checkEqualsNumeric(p,tmRl$p, msg="MCS: mathching p argument")
-   
-# winter air pollution data - dimension 5
-   tmWinterMCS <- MCS(winter,p)
-   myWinterMCS <- myMCS(t(winter),p)
-   checkEqualsNumeric(myWinterMCS,tmWinterMCS$mcs,msg="MCS: winter air pollution data")
-   
-# summer airpollution data - dimension 5
-   tmSummerMCS <- MCS(summer,p)
-   mySummerMCS <- myMCS(t(summer),p)
-   checkEqualsNumeric(mySummerMCS,tmSummerMCS$mcs,msg="MCS: summer air pollution data")
-}
