@@ -1,5 +1,4 @@
-`print.bootmex` <-
-function(x , ... ){
+print.bootmex <- function(x , ... ){
   print(x$call )
   cat(paste( "\n", x$R, " bootstrap samples created.\n\n" , sep = "" ) )
 
@@ -14,6 +13,4 @@ function(x , ... ){
 #  cat( paste("Dependence structure bootstrap mean parameter estimates:\n" ))
   cat("\n")
   invisible()
-}
-
-`show.bootmex` <- print.bootmex
+}
\ No newline at end of file
